// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

******************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION     *******
******************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
   global filesave "C:\Dropbox\21SP_PSQF6242\PSQF6242_Example4"
// Using UIowa virtual desktop instead
   //global filesave "\\Client\C:\Dropbox\21SP_PSQF6242\PSQF6242_Example4"

// We can then refer to the syntax variable "filesave" by putting $ in front

// IMPORT GSS_Example.xlsx data using filesave reference and exact file name
// To change all variable names to lowercase, remove "case(preserve")
   clear // Clear before means close any open data
   import excel "$filesave\GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (if need to start over)

// Create formats: set of value labels for categorical variables                           
   label define Fclass    1 "1.Lower" 2 "2.Middle" 3 "3.Upper"             
   label define Fhappy    1 "1.Unhappy" 2 "2.Neither" 3 "3.Fairly Happy" /// 
                             4 "4.Very Happy" 5 "5.Completely Happy"  
   
// Label variables and apply value formats for variables used below
// label variable name      "name: Descriptive Variable Label"
   label variable workclass "workclass: 3-Category Working Class"  
   label variable age       "age: Years of Age"
   label variable educ      "educ: Years of Education"
   label variable happy     "happy: 5-Category Happy Rating"
   label variable income    "income: Annual Income in 1000s"
   
// Apply value labels created above: name Format
   label values workclass Fclass   
   label values happy Fhappy
 
// Select cases complete on variables of interest
   egen nmiss = rowmiss(income workclass age educ happy)
   drop if nmiss>0
   
// Now dataset is ready to use

// Save results to separate text file
   log using $filesave\Example4_STATA_Output.log, replace 

   
******************************************************************************
*******       BEGIN DATA DESCRIPTION AND EMPTY MODEL FOR INCOME        *******
******************************************************************************

display "STATA Descriptive Statistics for Quantitative income"
format income %5.3f
summarize income, format detail // detail to get variance

display "STATA Histogram of Quantitative income"
histogram income, percent discrete width(5) start(0)      

display "STATA GLM Empty Model Predicting Income"
regress income, level(95)


******************************************************************************
*******       BEGIN PREDICTION OF INCOME BY 3-CATEGORY WORKCLASS       *******
******************************************************************************

display "STATA Descriptive Statistics for Categorical workclass"
tabulate workclass 

// STATA code to create dummy-coded binary predictors
   gen LvsM=. // Make two new empty variables
   gen LvsU=.
   replace LvsM=0 if workclass==1 // Replace each for lower
   replace LvsU=0 if workclass==1
   replace LvsM=1 if workclass==2 // Replace each for middle
   replace LvsU=0 if workclass==2
   replace LvsM=0 if workclass==3 // Replace each for upper
   replace LvsU=1 if workclass==3
   label variable LvsM "LvsM: Low=0 vs Mid=1 Class"
   label variable LvsU "LvsU: Low=0 vs Upp=1 Class"

display "STATA GLM Predicting Income from 3-Category workclass"
regress income c.LvsM c.LvsU, level(95)
// Ask for predicted income per group and group differences
   lincom _cons*1 + c.LvsM*0  + c.LvsU*0 // Low Mean 
   lincom _cons*1 + c.LvsM*1  + c.LvsU*0 // Mid Mean 
   lincom _cons*1 + c.LvsM*0  + c.LvsU*1 // Upp Mean 
   lincom           c.LvsM*1  + c.LvsU*0 // Low vs Mid Diff 
   lincom           c.LvsM*0  + c.LvsU*1 // Low vs Upp Diff 
   lincom           c.LvsM*-1 + c.LvsU*1 // Mid vs Upp Diff 

display "STATA regress adding beta to get standardized slopes for workclass"
regress income c.LvsM c.LvsU, beta // with beta, no longer shows unstandardized CIs


******************************************************************************
*******       BEGIN PREDICTION OF INCOME BY QUADRATIC YEARS OF AGE     *******
******************************************************************************

display "STATA Descriptive Statistics for Quantitative age"
format age %5.3f
summarize age, format detail // detail to get variance

display "STATA Histogram of Quantitative age"
histogram age, percent discrete width(2) start(18)

// STATA code to make new age variable centered at 18 (minimum in sample)
   gen age18 = age-18
   label variable age18 "age18: Age (0=18 years)"

display "STATA GLM Predicting Income from Linear Centered Age (0=18)"
regress income c.age18, level(95)
// Ask for predicted income for example ages
   lincom _cons*1 + c.age18*12  // Pred Income Age 30 (age18=12)
   lincom _cons*1 + c.age18*32  // Pred Income Age 50 (age18=32)
   lincom _cons*1 + c.age18*52  // Pred Income Age 70 (age18=52)

display  "STATA GLM Predicting Income from Quadratic Centered Age (0=18)"
regress income c.age18 c.age18#c.age18, level(95) // Hashtag (pound) multiplies predictors
// Ask for predicted income for example ages
   lincom _cons*1 + c.age18*12 + c.age18#c.age18*144  // Pred Income Age 30 (age18=12)
   lincom _cons*1 + c.age18*32 + c.age18#c.age18*1024 // Pred Income Age 50 (age18=32)
   lincom _cons*1 + c.age18*52 + c.age18#c.age18*2704 // Pred Income Age 70 (age18=52)
// Linear age slope changes by 2*quadratic coefficient, so multiply age*2
   lincom  c.age18*1 + c.age18#c.age18*24  // Pred Linear Age Slope at Age 30 (age18=12)
   lincom  c.age18*1 + c.age18#c.age18*64  // Pred Linear Age Slope at Age 50 (age18=32)
   lincom  c.age18*1 + c.age18#c.age18*104 // Pred Linear Age Slope at Age 70 (age18=52)

display "STATA regress adding beta to get standardized slopes for age"
regress income c.age18 c.age18#c.age18, beta // with beta, no longer shows CIs


******************************************************************************
*******   BEGIN PREDICTION OF INCOME BY PIECEWISE YEARS OF EDUCATION   *******
******************************************************************************
          
display "STATA Descriptive Statistics for Quantitative education"
format educ %5.3f
summarize educ, format detail // detail to get variance

display "STATA Histogram of Quantitative education"
histogram educ, percent discrete width(1) start(2)

// STATA code to make 3 new variables for sections of education
   gen lessHS=. // Make 3 new empty variables
   gen gradHS=.
   gen overHS=.
// Replace for educ less than 12
   replace lessHS=educ-11 if educ <  12
   replace gradHS=0       if educ <  12
   replace overHS=0       if educ <  12
// Replace for educ greater or equal to 12
   replace lessHS=0       if educ >= 12 
   replace gradHS=1       if educ >= 12
   replace overHS=educ-12 if educ >= 12
// Label variables
   label variable lessHS "lessHS: Slope for Years Ed Less Than High School"
   label variable gradHS "gradHS: Acute Bump for Graduating High School"
   label variable overHS "overHS: Slope for Years Ed After High School"

display "STATA GLM Predicting Income from Piecewise Education"
regress income c.lessHS c.gradHS c.overHS, level(95)
// Example of how to compare slopes
   lincom c.lessHS*-1 + c.gradHS*1 // Diff in ed slope:  2-11 vs 11-12
   lincom c.gradHS*-1 + c.overHS*1 // Diff in ed slope: 11-12 vs 12-20

display "STATA regress adding beta to get standardized slopes for education"
regress income c.lessHS c.gradHS c.overHS, beta // with beta, no longer shows CIs
   
   
******************************************************************************
*******   BEGIN PREDICTION OF INCOME BY ORDINAL 5-CATEGORY HAPPINESS   *******
******************************************************************************

display "STATA Descriptive Statistics for Categorical happy"
tabulate happy

// STATA code to make a single centered predictor for happy
   gen happy1=happy-1
   label variable happy1 "happy1: Happy Category (0=1)"
   
display "STATA GLM Predicting Income from Linear Centered Happy (0=1)"
regress income c.happy1, level(95)

// STATA code to make 4 new variables for adjacent values of happy
// Make 4 new empty variables
   gen h1v2=. 
   gen h2v3=. 
   gen h3v4=.
   gen h4v5=.
// Replace with 0s
   replace h1v2=0 if happy < 2
   replace h2v3=0 if happy < 3
   replace h3v4=0 if happy < 4
   replace h4v5=0 if happy < 5
// Replace with 1s
   replace h1v2=1 if happy >= 2
   replace h2v3=1 if happy >= 3
   replace h3v4=1 if happy >= 4
   replace h4v5=1 if happy == 5
// Label variables
   label variable h1v2 "Slope from Happy 1 to 2"
   label variable h2v3 "Slope from Happy 2 to 3"
   label variable h3v4 "Slope from Happy 3 to 4"
   label variable h4v5 "Slope from Happy 4 to 5"

display "STATA GLM Predicting Income from Piecewise Adjacent Slopes for Happy"
regress income c.h1v2 c.h2v3 c.h3v4 c.h4v5, level(95)
// Example of how to compare slopes
   lincom c.h1v2*-1 + c.h2v3*1 // Diff in Slope 1-2 vs Slope 2-3
   lincom c.h2v3*-1 + c.h3v4*1 // Diff in Slope 2-3 vs Slope 3-4
   lincom c.h3v4*-1 + c.h4v5*1 // Diff in Slope 3-4 vs Slope 4-5

display "STATA regress adding beta to get standardized slopes for happy"
regress income c.h1v2 c.h2v3 c.h3v4 c.h4v5, beta // with beta, no longer shows CIs

// Close log
log close  

       
       



